{% extends 'cms/blocks/_block.html' %}
{% load wagtailcore_tags %}

{% block block_content %}
    <div class="stream-content-container {{ value.align }} {% if value.animation and not amp %}animation fade-up{% endif %}">
        {% for stream in value.content %}
            {% include_block stream with align=value.align %}
        {% endfor %}
    </div>
{% endblock %}
