{% extends "wagtailadmin/base.html" %}
{% load static %}

{% comment %}
{% block extra_css %}
    <link href="/static/dist/css/wagtail{{ request.version_webspace }}.css" rel="stylesheet" type="text/css"/>
{% endblock %}
{% endcomment %}
