# Generated by Django 3.0.7 on 2020-07-24 18:11

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='TaskBuild',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('date_start', models.DateTimeField(auto_now=True, null=True)),
                ('date_end', models.DateTimeField(blank=True, null=True)),
                ('task_id', models.CharField(blank=True, default=None, max_length=100, null=True)),
                ('ready', models.BooleanField(default=False)),
            ],
            options={
                'ordering': ['-date_start'],
            },
        ),
    ]
