# Generated by Django 3.0.7 on 2020-07-28 17:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0015_auto_20200727_2232'),
    ]

    operations = [
        migrations.AddField(
            model_name='webspacesettings',
            name='button_view_all_articles',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
        migrations.AddField(
            model_name='webspacesettings',
            name='button_view_all_portfolios',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
    ]
