{% extends 'cms/blocks/_block.html' %}
{% load wagtailcore_tags %}

{% block block_content %}
    <div class="articles-container">
        {% for blog in value.articles %}
            {% include 'cms/blocks/common/article.html' with blog=blog.value theme=value.theme %}
        {% endfor %}
    </div>
{% endblock %}
