{% extends 'cms/blocks/_block.html' %}
{% load wagtailcore_tags %}

{% block block_theme_bg %}{% if value.theme_reverse and value.theme_reverse != value.theme %}{{ block.super }}-{{ value.theme_reverse }}{% else %}{{ block.super }}{% endif %}{% endblock block_theme_bg %}
{% block theme %}{% if value.theme_content %}theme-{{ value.theme_content }}{% else %}theme-{{ value.theme }}{% endif %}{% endblock %}

{% block block_content %}
    {% include_block value.form with theme=value.theme_content %}
{% endblock %}
