{% extends 'cms/blocks/_block.html' %}
{% load wagtailcore_tags %}

{% block block_content %}
    <div class="numbers-container">
        {% for item in value.items %}
            <div class="number">
                <div class="number-nb">
                    <span class="counter-up">{{ item.value.number }}</span>
                    <span>{{ item.value.unit }}</span>
                </div>
                <div class="content">
                    {{ item.value.content.value|richtext }}
                </div>
            </div>
        {% endfor %}
    </div>
{% endblock %}