# Generated by Django 3.0.7 on 2020-07-02 17:47

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0002_auto_20200702_1608'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='cover',
        ),
        migrations.AddField(
            model_name='user',
            name='description',
            field=models.TextField(blank=True, default='', help_text='Description'),
        ),
    ]
