# Generated by Django 3.0.7 on 2020-07-02 17:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0022_uploadedimage'),
        ('account', '0003_auto_20200702_1747'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='image_presentation',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Image presentation'),
        ),
        migrations.AlterField(
            model_name='user',
            name='description',
            field=models.TextField(blank=True, default='', help_text='Bio'),
        ),
    ]
