# Generated by Django 3.0.7 on 2020-07-02 16:08

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0022_uploadedimage'),
        ('account', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='cover',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Formulaire'),
        ),
        migrations.AddField(
            model_name='user',
            name='facebook',
            field=models.URLField(blank=True, help_text='Facebook page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='instagram',
            field=models.URLField(blank=True, help_text='Instagram page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='linkedin',
            field=models.URLField(blank=True, help_text='Linkedin page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='pinterest',
            field=models.URLField(blank=True, help_text='Pinterest page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='twitter',
            field=models.URLField(blank=True, help_text='Twitter page URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='youtube',
            field=models.URLField(blank=True, help_text='Youtube page URL'),
        ),
    ]
