# Generated by Django 3.0.7 on 2020-07-02 18:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0004_auto_20200702_1758'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='calendly',
            field=models.URLField(blank=True, help_text='Calendly URL'),
        ),
        migrations.AddField(
            model_name='user',
            name='title',
            field=models.CharField(blank=True, default='', help_text='Titre', max_length=200),
        ),
    ]
