{% extends 'cms/blocks/_block.html' %}
{% load wagtailcore_tags my %}

{% block block_content %}
    <div class="medias-line-container">
        {% for item in value.medias %}
            <a href="{% if item.value.link %}{{ item.value.link }}{% elif item.value.page %}{% pageurl item.value.page %}{% endif %}">
                <div class="media-line-item">
                    {% if item.block_type == 'svg_label' %}
                        {% include 'cms/blocks/common/svg.html' with value=item.value block_num=block_num %}
                    {% elif item.block_type == 'image_label' %}
                        {% include 'cms/blocks/common/picture.html' with img=item.value.file block_num=block_num theme=value.theme|theme_reverse %}
                    {% endif %}
                    {% if item.value.label %}
                        <div class="label-container">
                            <h3 class="label">{{ item.value.label }}</h3>
                        </div>
                    {% endif %}
                </div>
            </a>
        {% endfor %}
    </div>
{% endblock %}
