<div class="gallery-slider-container">
    {% include 'cms/blocks/common/bg.html' with bg_desktop=value.gallery.medias bg_mobile=value.gallery.medias pos="center" slider=1 rendition_mobile='width-600' rendition_desktop='width-900' %}
</div>
