html,body{background:#171721}#loader{z-index:10000000000000;position:fixed;top:0;left:0;bottom:0;right:0;transition:opacity 0.5s ease}#loader img{width:20px;position:absolute;top:50%;left:50%;transform:translateX(-50%) translateY(-50%)}* ::-webkit-scrollbar{width:5px;height:5px}* ::-webkit-scrollbar-track{background:#171721}* ::-webkit-scrollbar-thumb{background:#F7F7F7}* ::-webkit-scrollbar-thumb:hover{background:#F7F7F7}#loader ~ div{display:none}
