select {

  @include theme($themes) {
    color: t('colorP');
    background: t('uks');
  }
  font-size: 18px;
  border-radius: 4px;
  border: none;

  option {
    padding: 10px 20px;
    border: none;
  }
}

.select {
  select {
    padding: 10px 20px;
  }
}
