{% extends 'cms/blocks/_block.html' %}
{% load wagtailcore_tags %}

{% block block_content %}
    <div class="articles-container">
        {% for portfolio in value.portfolios %}
            {% include 'cms/blocks/common/portfolio.html' with portfolio=portfolio.value theme=theme|theme_reverse %}
        {% endfor %}
    </div>
{% endblock %}
