{% extends 'cms/blocks/schemas/_schema.html' %}

{% block json %}
{
  "@context": "https://schema.org",
  "@type": "FAQPage",
  "mainEntity": [
  {% for question in value.questions %}
  {
    "@type": "Question",
    "name": "{{ question.value.question }}",
    "acceptedAnswer": {
      "@type": "Answer",
      "text": "{{ question.value.answer }}"
    }
  }{% if not forloop.last %},{% endif %}
  {% endfor %}
  ]
}
{% endblock %}
