$screen-xs-min: 480px !default;
$screen-sm-min: 768px !default;
$screen-md-min: 901px !default;
$screen-lg-min: 1171px !default;
$screen-lg-med: 1260px !default;
$screen-xs-max: ($screen-sm-min - 1) !default;
$screen-sm-max: ($screen-md-min - 1) !default;
$screen-md-max: ($screen-lg-min - 1) !default;

@mixin xs {
  @media (max-width: $screen-xs-max) {
    @content;
  }
}

@mixin sm {
  @media (min-width: $screen-sm-min) and (max-width: $screen-sm-max) {
    @content;
  }
}

@mixin md {
  @media (min-width: $screen-md-min) {
    @content;
  }
}

@mixin xssm {
  @media (max-width: $screen-sm-max) {
    @content;
  }
}
