!function(e){var t={};function o(n){if(t[n])return t[n].exports;var r=t[n]={i:n,l:!1,exports:{}};return e[n].call(r.exports,r,r.exports,o),r.l=!0,r.exports}o.m=e,o.c=t,o.d=function(e,t,n){o.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:n})},o.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},o.t=function(e,t){if(1&t&&(e=o(e)),8&t)return e;if(4&t&&"object"==typeof e&&e&&e.__esModule)return e;var n=Object.create(null);if(o.r(n),Object.defineProperty(n,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var r in e)o.d(n,r,function(t){return e[t]}.bind(null,r));return n},o.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return o.d(t,"a",t),t},o.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},o.p="/",o(o.s=6)}({6:function(e,t,o){"use strict";function n(e,t){const o=t.getBoundingClientRect().top-document.body.getBoundingClientRect().top;t.getBoundingClientRect().bottom-e.offsetHeight<0?(e.style.position="absolute",e.style.top="unset",e.style.bottom="0"):document.documentElement.scrollTop>o?(e.style.position="fixed",e.style.top="0px",e.style.bottom="unset"):(e.style.position="absolute",e.style.top="unset",e.style.bottom="unset")}o.r(t);var r={summary:()=>{const e=document.getElementById("blog-content-container"),t=document.getElementById("block-summary");n(t,e),window.addEventListener("scroll",()=>{n(t,e)})},summaryTitles:()=>{const e=document.getElementById("block-summary"),t=new IntersectionObserver(t=>t.forEach(t=>{const o=t.target;if(t.isIntersecting){e.querySelectorAll('a[class^="active"]').forEach(e=>e.classList.remove("active"));e.querySelector(`a[href="#${o.id}"]`).classList.add("active")}}));document.querySelectorAll('h2[id^="titles"]').forEach(e=>t.observe(e))}};r.summary(),r.summaryTitles()}});