{% if not amp and not debug %}
    <script>
        window.ga=window.ga||function(){(ga.q=ga.q||[]).push(arguments)};ga.l=+new Date;
        ga('create', '{% if not debug %}{{ settings.cms.WebspaceSettings.ga_code }}{% else %}UA-126298837-2{% endif %}', 'auto');
        ga('send', 'pageview');
    </script>
    <script async src='https://www.google-analytics.com/analytics.js'></script>
{% endif %}
{% if amp and not debug %}
    <script async custom-element="amp-analytics" src="https://cdn.ampproject.org/v0/amp-analytics-0.1.js"></script>
{% endif %}
