{% extends 'cms/blocks/schemas/_schema.html' %}
{% load wagtailcore_tags wagtailimages_tags my %}

{% block json %}
    {
    "@context": "http://schema.org",
    "@type": "HowTo",
    "image": {
    "@type": "ImageObject",
    "url": "{% image page.feed_image fill-500x500 as img %}{{ img.url }}"
    },
    "name": "Quels sont les articles {% if current_tag %}{{ current_tag }}{% endif %} de {{ settings.cms.WebspaceSettings.brand_name }}?",
    "step":[
    {% for blog in items %}
        {
        "@type": "HowToStep",
        "name": "{{ blog.title }}",
        "text": "{{ blog.intro }}",
        "image": "{% image blog.feed_image fill-500x500 as img %}{{ img.url }}",
        "url": "{{ blog.url }}"
        }{% if not forloop.last %},{% endif %}
    {% endfor %}
    ]}
{% endblock %}
