.s-center {
  text-align: center;
}

.s-flex-align {
  display: flex;
  align-items: center;
}

.s-flex-jc {
  justify-content: center;
}

.s-cursor {
  cursor: pointer;
}

.s-nopad {
  padding: 0;
}

.shadow {
  text-shadow: 0 1px 3px rgba(0, 0, 0, 0.4);
}
