# Generated by Django 3.0.9 on 2020-08-25 15:35

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0020_auto_20200825_1734'),
    ]

    operations = [
        migrations.RenameField(
            model_name='webspacesettings',
            old_name='secondary_color',
            new_name='secondary_bg_color',
        ),
    ]
