.gallery-container {
  ul {
    display: flex;
    flex-wrap: wrap;
    padding: 2vmin;
    list-style: none;
    margin: 0;
  }

  li {
    height: 20vh;
    flex-grow: 1;
    padding: 1vmin;
  }

  li:last-child {
    flex-grow: 10;
  }

  img {
    max-height: 100%;
    min-width: 100%;
    object-fit: cover;
    vertical-align: bottom;
    border-radius: 1vmin;
  }

  // Portrait

  @media (max-aspect-ratio: 1/1) {
    li {
      height: 30vh;
    }
  }

  // Short screens

  @media (max-height: 480px) {
    li {
      height: 80vh;
    }
  }

  // Smaller screens in portrait

  @media (max-aspect-ratio: 1/1) and (max-width: 480px) {
    ul {
      flex-direction: row;
    }

    li {
      height: auto;
      width: 100%;
    }
    img {
      width: 100%;
      max-height: 75vh;
      min-width: 0;
    }
  }
}
