{% extends 'cms/blocks/_block.html' %}
{% load wagtailcore_tags %}

{% block block_content %}
    <div id="accordion-{{ block_num }}" class="accordion-container">
        {% for item in value.items %}
            <section class="ac">
                <div class="ac-q" tabindex="0">
                    <div class="rich-text">
                        {{ item.value.head.value|richtext }}
                    </div>
                </div>
                <div class="ac-a">
                    <div class="rich-text">
                        {{ item.value.content.value|richtext }}
                    </div>
                </div>
            </section>
        {% endfor %}
    </div>
{% endblock %}
