@mixin keyframes($name) {
  @-webkit-keyframes #{$name} {
    @content;
  }
  @-moz-keyframes #{$name} {
    @content;
  }
  @-ms-keyframes #{$name} {
    @content;
  }
  @keyframes #{$name} {
    @content;
  }
}

/* Fade Up */

.fade-up {
  opacity: 0;
  transform: translate3d(0, 40px, 0)
}

.fade-up.start {
  opacity: 1;
  transform: translate3d(0, 0, 0);
  animation: fadeUp ease 1.5s;
  -webkit-animation: fadeUp ease 1.5s;
  -moz-animation: fadeUp ease 1.5s;
  -o-animation: fadeUp ease 1.5s;
  -ms-animation: fadeUp ease 1.5s;
}


.fade-in {
  opacity: 1;
  animation: fadeIn ease 1.5s;
  -webkit-animation: fadeIn ease 1.5s;
  -moz-animation: fadeIn ease 1.5s;
  -o-animation: fadeIn ease 1.5s;
  -ms-animation: fadeIn ease 1.5s;
}

.fade-out {
  opacity: 0;
  animation: fadeOut ease 1.5s;
  -webkit-animation: fadeOut ease 1.5s;
  -moz-animation: fadeOut ease 1.5s;
  -o-animation: fadeOut ease 1.5s;
  -ms-animation: fadeOut ease 1.5s;
}


@include keyframes(fadeUp) {
  0% {
    opacity: 0;
    transform: translate3d(0, 40px, 0)
  }
  100% {
    opacity: 1;
    transform: translate3d(0, 0, 0);
  }
}

@include keyframes(fadeIn) {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}

@include keyframes(fadeOut) {
  0% {
    opacity: 1;
  }
  100% {
    opacity: 0;
  }
}