# Generated by Django 3.0.7 on 2020-07-29 09:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0016_auto_20200728_1712'),
    ]

    operations = [
        migrations.AddField(
            model_name='portfoliopage',
            name='intro_title',
            field=models.CharField(blank=True, default='', help_text="Titre d'introduction qui s'affiche sur un block portfolio de présentation", max_length=500),
        ),
    ]
