.theme-bg-space{background:#171721}.theme-bg-space-inverse{background:#20202C}.theme-bg-light{background:#F7F7F7}.error{color:#9A1F20 !important}.theme-bg-space-space-inverse{background:linear-gradient(to bottom, #171721 0%, #171721 50%, #20202C 50%, #20202C 100%)}.theme-bg-space-light{background:linear-gradient(to bottom, #171721 0%, #171721 50%, #F7F7F7 50%, #F7F7F7 100%)}.theme-bg-space-inverse-space{background:linear-gradient(to bottom, #20202C 0%, #20202C 50%, #171721 50%, #171721 100%)}.theme-bg-space-inverse-light{background:linear-gradient(to bottom, #20202C 0%, #20202C 50%, #F7F7F7 50%, #F7F7F7 100%)}.theme-bg-light-space{background:linear-gradient(to bottom, #F7F7F7 0%, #F7F7F7 50%, #171721 50%, #171721 100%)}.theme-bg-light-space-inverse{background:linear-gradient(to bottom, #F7F7F7 0%, #F7F7F7 50%, #20202C 50%, #20202C 100%)}.logo{width:95%;margin:2em auto;padding:.6em 0}
