.stream-content-container {
  display: flex;
  flex-direction: column;

  &.right {
    align-items: flex-end;
  }

  &.center {
    align-items: center;
  }

  .rich-text-container {
    max-width: 750px;
  }
}
