# Generated by Django 3.0.7 on 2020-07-02 20:18

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('account', '0005_auto_20200702_1830'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='calendly',
        ),
        migrations.RemoveField(
            model_name='user',
            name='description',
        ),
        migrations.RemoveField(
            model_name='user',
            name='facebook',
        ),
        migrations.RemoveField(
            model_name='user',
            name='image_presentation',
        ),
        migrations.RemoveField(
            model_name='user',
            name='instagram',
        ),
        migrations.RemoveField(
            model_name='user',
            name='linkedin',
        ),
        migrations.RemoveField(
            model_name='user',
            name='pinterest',
        ),
        migrations.RemoveField(
            model_name='user',
            name='title',
        ),
        migrations.RemoveField(
            model_name='user',
            name='twitter',
        ),
        migrations.RemoveField(
            model_name='user',
            name='youtube',
        ),
    ]
