$margin-card: 30px 10px;
$margin-card-xs: 30px 0;

$border-radius-card: 10px;

.cards {
  position: relative;

  .cards-container {

    &.nocarousel {
      display: flex;
      justify-content: center;

      @include xssm() {
        display: inline-block;
      }

      .card {
        @include xssm() {
          margin: $margin-card-xs;
        }
      }
    }

    &.amp-carousel {
      width: 100%;
      overflow-x: hidden;

      .amp-carousel-slide {
        white-space: normal;
      }


      .card {
        width: 300px;
        margin: 25px 10px;

        .tag-container.inline {
          display: flex;
        }
      }
    }

    &.carousel {
      @include xs() {
        width: 300px;
        margin: auto;
      }
      @include sm() {
        width: 100%;
      }
      @include md() {
        width: 100%;
      }

      display: flex;
      overflow-x: hidden;
      position: relative;

      .card {
        min-width: 255px;
        margin: 30px 25px;
      }
    }
  }
}

.card {
  width: 100%;
  @include md() {
    margin: $margin-card;
  }

  &.nopad {
    margin: 0;
  }

  &.person {

    .person-name {
      min-height: 70px;
    }

    .person-profil {
      width: 50%;
      text-align: center;
      margin: auto;

      img {
        width: 100%;
      }
    }
  }

  .card-icon {
    position: absolute;
    left: 50%;
    top: 0;
    transform: translateX(-50%) translateY(-50%);
    border-radius: 50%;
    width: 50px;
    height: 50px;

    .nopad {
      margin: auto;
    }
  }

  .card-icon.noamp {
    img {
      position: absolute;
      left: 50%;
      top: 50%;
      transform: translateX(-50%) translateY(-50%);
    }
  }

  .card-content {
    padding: 20px;

    .review-star {
      display: inline-block;
    }
  }
}
