# Generated by Django 3.0.7 on 2020-07-22 17:40

from django.db import migrations
import modelcluster.contrib.taggit


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0003_taggeditem_add_unique_index'),
        ('cms', '0012_auto_20200722_1734'),
    ]

    operations = [
        migrations.AlterField(
            model_name='portfoliopage',
            name='tags',
            field=modelcluster.contrib.taggit.ClusterTaggableManager(blank=True, help_text='A comma-separated list of tags.', through='cms.PortfolioPageTag', to='taggit.Tag', verbose_name='Tags'),
        ),
    ]
