$media-line-margin: 5px;

.medias-line-container {
  display: flex;

  @include xssm() {
    display: block;
    width: 100%;
    text-align: center;
  }

  a {
    display: inline-block;
    text-decoration: unset;
    width: 100%;
    height: 100%;
  }

  .media-line-item {
    flex: 1;
    position: relative;
    margin: $media-line-margin;

    img {
      width: 100%;
    }

    @include xssm() {
      display: inline-block;
    }

    @include xs() {
      width: 80%;
    }

    @include sm() {
      width: 40%;
    }

    .label-container {
      position: absolute;
      bottom: 0;
      width: 100%;
      background: rgba(247, 247, 247, 0.3);

      .label {
        text-align: center;
        overflow: hidden;
        white-space: nowrap;
        text-overflow: ellipsis;
        margin: 0 10px;
      }
    }
  }
}
