# Generated by Django 3.0.7 on 2020-07-03 11:28

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailimages', '0022_uploadedimage'),
        ('cms', '0003_auto_20200702_1538'),
    ]

    operations = [
        migrations.CreateModel(
            name='Person',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('help_text', models.CharField(blank=True, default='', max_length=100)),
                ('first_name', models.CharField(blank=True, default='', max_length=200)),
                ('last_name', models.CharField(blank=True, default='', max_length=200)),
                ('title', wagtail.core.fields.RichTextField(blank=True, default='', help_text='Titre')),
                ('description', wagtail.core.fields.RichTextField(blank=True, default='', help_text='Bio')),
                ('email_contact', models.CharField(blank=True, default='', max_length=200)),
                ('facebook', models.URLField(blank=True, help_text='Facebook page URL')),
                ('instagram', models.URLField(blank=True, help_text='Instagram page URL')),
                ('linkedin', models.URLField(blank=True, help_text='Linkedin page URL')),
                ('twitter', models.URLField(blank=True, help_text='Twitter page URL')),
                ('pinterest', models.URLField(blank=True, help_text='Pinterest page URL')),
                ('youtube', models.URLField(blank=True, help_text='Youtube page URL')),
                ('calendly', models.URLField(blank=True, help_text='Calendly URL')),
                ('image_miniature', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Image Miniature')),
                ('image_presentation', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Image Presentation')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
