{% extends 'cms/blocks/_block.html' %}
{% load wagtailcore_tags %}

{% block block_content %}
    <amp-accordion disable-session-states animate>
        {% for item in value.items %}
        <section class="ac">
            <header class="ac-q" tabindex="0">
                {{ item.value.head.value|richtext }}
            </header>
            <div class="ac-a">
                {{ item.value.content.value|richtext }}
            </div>
        </section>
        {% endfor %}
    </amp-accordion>
{% endblock %}
