# Generated by Django 3.0.7 on 2020-07-29 14:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bakery', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='VersionBuild',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(blank=True, default=None, max_length=100, null=True)),
                ('total_build', models.IntegerField(default=0)),
            ],
        ),
    ]
