import Cms from './helpers/Cms';


(function initCMS() {
  Cms.SmoothScroll.init();
  Cms.Carousel.init();
  Cms.Clicker.init();
  Cms.Aside.mobile();
  Cms.Lazy.init();
  Cms.Collect.init();
  Cms.Accordion.init();
  Cms.CounterUp.init();
  Cms.Animation.init();
  Cms.BgSlide.init();
}());
