{% load wagtailcore_tags %}

{% with theme=page.theme %}
    <div id="block-social-share-{{ block_num }}"
         class="{% if block_num == 1 %}header-padding {% endif %}social-share theme-bg-{{ theme }}">
        <div class="container content theme-{{ theme }}">
            <div class="rich-text-container align-text-center">
                {% block social_head_text %}
                {% endblock %}
            </div>
            <div class="socials">
                {% block social_action %}
                {% endblock social_action %}
            </div>

            {% with newsletter=settings.cms.WebspaceSettings.newsletter %}
                {% if newsletter %}
                    {% include 'cms/blocks/common/form.html' with form=newsletter theme=theme %}
                {% endif %}
            {% endwith %}

        </div>
    </div>
{% endwith %}