# Generated by Django 3.0.7 on 2020-07-06 14:50

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0004_person'),
    ]

    operations = [
        migrations.AddField(
            model_name='genericpage',
            name='amp_active',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='blogpage',
            name='author',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='cms.Person'),
        ),
    ]
